<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\CandidatoEstudiante;
use App\User;
use App\FechaVotaciones;
use App\RegistroVoto;
use App\ConcejoDirectivo;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;

class EstudianteController extends Controller
{
    
    public function __construct(){

                     $this->middleware("Estudiante");

    }

    public function index(){

                    return view("estudiante.estudiante");

    }

    public function validarCodigoEstudiante(Request $request){

                    $usuario = Auth::user();
                    $datos   = [
                        "titulo"    => "Codigo de votación",
                        "contenido" => "$usuario->codigoVotacion es su codigo de votación"
                    ];

                    Mail::send("email.test",$datos,function($mensaje){

                        $usuario = Auth::user();
                        $mensaje ->to(
                            $usuario['email'],
                            $usuario['name'])->subject("Codigo de votación");
                    });

                    return view("estudiante.validarCodigoEstudiante",compact("request"));
    }

    public function votarEstudiante(Request $request){
        
                    $usuario = Auth::user();
                    
                    if($usuario->codigoVotacion == $request->codigoVotacion){

                    date_default_timezone_set('America/Bogota');
                    $fechaActual = explode("/",date("Y-m-d h:i:s"));
                    
                    $concejoId = ConcejoDirectivo::where("nombre","estudiante")->first();

                    FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                    ->update([
                        "fechaActual" => $fechaActual[0],
                    ]);

                    $fecha = FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                    ->where("fechaActual",$fechaActual[0])
                    ->orderByDesc("id")
                    ->first();
                    
                    $votoUsuario = RegistroVoto::where("user_id",$usuario["id"])
                    ->where("fecha_votacione_id",$fecha["id"])
                    ->get();    
                    
                    if (count($votoUsuario)) {
                        $mensajeAlerta = "Usted ya ha votado Gracias!";
                        return view("estudiante.estudiante",compact("mensajeAlerta"));
                    }

                    
                    $votos = CandidatoEstudiante::select("votos")
                    ->where("user_id",$request->user_id)
                    ->where("fecha_votacione_id",$fecha["id"])
                    ->first();
                
                    CandidatoEstudiante::where("user_id",$request->user_id)
                    ->where("fecha_votacione_id",$fecha["id"])
                    ->update([
                        "votos" => $votos["votos"]+1,
                    ]);

                    RegistroVoto::create([
                        "user_id" => $usuario["id"],
                        "fecha_votacione_id" => $fecha["id"]
                    ]);

                    $mensaje="¡ Voto asignado con exito !";
                    return view("estudiante.estudiante",compact("mensaje"));

                    }else{
                        $mensajeError="Codigo de votación invalido";
                        return view("estudiante.estudiante",compact("mensajeError"));
                    }
                }

    public function resultadoEstudiante(){

                   $concejoId = ConcejoDirectivo::where("nombre","Estudiante")->first();

                   $fechaVotaciones = FechaVotaciones::select("id")
                   ->where("concejo_directivo_id",$concejoId["id"])
                   ->orderByDesc("id")
                   ->first();

                    $candidatos = CandidatoEstudiante::where("fecha_votacione_id",$fechaVotaciones["id"])
                    ->orderByDesc("votos")
                    ->get();

                    return view("estudiante.resultadoEstudiante",compact("candidatos"));

    }

    public function candidatosEstudiante(){

                    date_default_timezone_set('America/Bogota');
                    $fechaActual = explode("/",date("Y-m-d h:i:s"));

                    $concejoId = ConcejoDirectivo::where("nombre","estudiante")->first();

                    FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                    ->update([
                        "fechaActual" => $fechaActual[0],
                    ]);
                    
                    $fecha = FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                    ->where("fechaActual",$fechaActual[0])
                    ->orderByDesc("id")
                    ->first();

                    $candidatos = candidatoEstudiante::all();
                
                    $fechaVotaciones = FechaVotaciones::whereBetween("fechaActual",array($fecha["fechaInicio"],$fecha["fechaFinal"]))
                    ->where("concejo_directivo_id",$concejoId["id"])
                    ->get();

                    return view("estudiante.candidatosEstudiante", compact("candidatos","fechaVotaciones"));

    }

    public function postularse(){

                    return view("estudiante.postularEstudiante");

    }

    public function crearPostulacion(Request $request){
        
                    date_default_timezone_set('America/Bogota');
                    $fechaActual = explode("/",date("Y-m-d h:i:s"));
                    
                    $concejoId = ConcejoDirectivo::where("nombre","estudiante")->first();
                    
                    FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                    ->update([
                        "fechaActual" => $fechaActual[0],
                    ]);
                
                    $fecha = FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                    ->where("fechaActual",$fechaActual[0])
                    ->orderByDesc("id")
                    ->first();

                    $fechaVotaciones = FechaVotaciones::whereBetween("fechaActual",array($fecha["fechaInicio"],$fecha["fechaFinal"]))
                    ->where("concejo_directivo_id",$concejoId["id"])
                    ->get();

                    if (count($fechaVotaciones)) {
                            $this->validate($request,[
                            "perfil" => ["required" , "string"],
                            "user_id" => ["unique:candidato_estudiantes"],
                            "planGobierno" => ["required" , "string"]
                        ]);
                
                        candidatoEstudiante::create([
                            "user_id" => $request->user_id,
                            "perfil" => $request->perfil,
                            'trayectoriaUno' => "$request->trayectoriaUno",
                            "trayectoriaDos" => $request->trayectoriaDos,
                            "trayectoriaTres" => $request->trayectoriaTres,
                            "trayectoriaCuatro" => $request->trayectoriaCuatro,
                            "planGobierno" => $request->planGobierno,
                            "fecha_votacione_id" => $fechaVotaciones[0]["id"],
                        ]);
                        
                        $mensaje = "Postulación registrada exitosamente";
                        return view("estudiante.estudiante",compact("mensaje"));    

                    }else{

                        $mensajeError = "No se puede realizar la postulación";
                        return view("estudiante.estudiante",compact("mensajeError"));

                    }  
    }

    

}
