<?php

namespace App;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Contracts\Auth\CanResetPassword;
use Illuminate\Database\Eloquent\SoftDeletes;
use App\Notifications\UserResetPassword;

class User extends Authenticatable
{
    use Notifiable;
    use SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'email', 'password','primerApellido','segundoApellido','carrera_id',
        'semestre','tipoDocumento_id','numeroDocumento','fechaExpedicion','telefono',
        'celular','direccion','ciudad_id','codigoVotacion','foto','role_id'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];


    public function role(){

        return $this->belongsTo("App\Role");

    }

    public function docente(){

        if ($this->role->nombre_rol == 'Docente') {
            return true;
        }

        return false;

    }
    public function estudiante(){

        if ($this->role->nombre_rol == 'Estudiante') {
            return true;
        }

        return false;

    }

    public function administrador(){

        if($this->role->nombre_rol == "Administrador"){

            return true;

        }
        return false;

    }

    public function sendPasswordResetNotification($token)
    {
        $this->notify(new UserResetPassword($token));
    }
}
